==> SpatialVx_0.7-1.tar.gz: SpatialVx/man/SpatialVx-internal.Rd <==
\name{SpatialVx-internal}
\alias{print.G2IL} 
\alias{print.Gbeta}
\alias{print.GbetaIL} 
\alias{ubalancer}
\alias{calculate_FSS_from_enlarged_summed_fields}
\alias{calculate_FSSvector_from_enlarged_summed_fields}
\alias{calculate_fractions_from_enlarged_summed_field}
\alias{calculate_n05_using_bisection_from_the_summed_fields}
\alias{calculate_summed_field}
\alias{enlarge_matrix}
\alias{datagrabber}
\alias{datagrabber.SpatialVx}
\alias{datagrabber.features}
\alias{datagrabber.matched}
\alias{deltammSqCen}
\alias{deltammOrig}
\alias{FeatureMatchAnalyzer.matched}
\alias{MergeIdentifier}
\alias{hoods2dPrep}
\alias{hoods2dSetUpLists}
\alias{KernelGradFUN}
\alias{locmeasures2dPrep}
\alias{LocListSetup}
\alias{MakeClusterList}
\alias{makeEmptyWave}
\alias{makeWaveNames}
\alias{ORSS}
\alias{QlossRigid}
\alias{QcorrRigid}
\alias{inside}
\alias{CI.fun}
\alias{sig.coverage}
\alias{is.sig}
\alias{detailer}
\alias{energizer}
\alias{variogram.matrix}
\alias{initGMM}
\alias{gmmEMstep}
\alias{gmmNegLogLik}
\alias{grads1}
\alias{grads2}
\alias{plot.matchedMap}
\alias{plot.matchedNoMap}
\alias{plot.saller}
\alias{plot.SpatialVxMap}
\alias{plot.SpatialVxNoMap}
\alias{plot.variographied}
\alias{plot.wavePurifyVxFieldsMap}
\alias{plot.wavePurifyVxFieldsNoMap}
\alias{plot.wavePurifyVxStats}
\alias{print.summary.interester}
\alias{print.variographied}
\alias{shrinkgrid}
\alias{Q}
\alias{Qgauss}
\alias{Qnonzero}
\alias{dF}
\alias{iwarper}
\alias{plot.iwarped}
\alias{plot.warped}
\alias{plot.warped.lonlat}
\alias{print.warped}
\alias{prinwarp}
\alias{summary.iwarped}
\alias{summary.warped}
\alias{warpTps}
\alias{warpTpsConverter}
\alias{warpTpsMatrices} 
\alias{warper}
\alias{warpingRadialBasis}
\alias{equal.axis}
\title{
Internal functions for the SpatialVx package
}
\description{
Not to be called by the user.
}

\keyword{ internal}

==> SpatialVx_0.8.tar.gz: SpatialVx/man/SpatialVx-internal.Rd <==
\name{SpatialVx-internal}
\alias{print.G2IL} 
\alias{print.Gbeta}
\alias{print.GbetaIL} 
\alias{print.TheBigG}
\alias{ubalancer}
\alias{calculate_FSS_from_enlarged_summed_fields}
\alias{calculate_FSSvector_from_enlarged_summed_fields}
\alias{calculate_fractions_from_enlarged_summed_field}
\alias{calculate_n05_using_bisection_from_the_summed_fields}
\alias{calculate_summed_field}
\alias{enlarge_matrix}
\alias{datagrabber}
\alias{datagrabber.SpatialVx}
\alias{datagrabber.features}
\alias{datagrabber.matched}
\alias{deltammSqCen}
\alias{deltammOrig}
\alias{FeatureMatchAnalyzer.matched}
\alias{MergeIdentifier}
\alias{hoods2dPrep}
\alias{hoods2dSetUpLists}
\alias{KernelGradFUN}
\alias{locmeasures2dPrep}
\alias{LocListSetup}
\alias{MakeClusterList}
\alias{makeEmptyWave}
\alias{makeWaveNames}
\alias{ORSS}
\alias{QlossRigid}
\alias{QcorrRigid}
\alias{inside}
\alias{CI.fun}
\alias{sig.coverage}
\alias{is.sig}
\alias{detailer}
\alias{energizer}
\alias{variogram.matrix}
\alias{initGMM}
\alias{gmmEMstep}
\alias{gmmNegLogLik}
\alias{grads1}
\alias{grads2}
\alias{plot.matchedMap}
\alias{plot.matchedNoMap}
\alias{plot.saller}
\alias{plot.SpatialVxMap}
\alias{plot.SpatialVxNoMap}
\alias{plot.variographied}
\alias{plot.wavePurifyVxFieldsMap}
\alias{plot.wavePurifyVxFieldsNoMap}
\alias{plot.wavePurifyVxStats}
\alias{print.summary.interester}
\alias{print.variographied}
\alias{shrinkgrid}
\alias{Q}
\alias{Qgauss}
\alias{Qnonzero}
\alias{dF}
\alias{iwarper}
\alias{plot.iwarped}
\alias{plot.warped}
\alias{plot.warped.lonlat}
\alias{print.warped}
\alias{prinwarp}
\alias{summary.iwarped}
\alias{summary.warped}
\alias{warpTps}
\alias{warpTpsConverter}
\alias{warpTpsMatrices} 
\alias{warper}
\alias{warpingRadialBasis}
\alias{equal.axis}
\alias{calculate_NSS_from_enlarged_summed_fields}
\alias{calculate_dNSS}
\alias{calculate_n_NSS05_using_bisection_from_the_summed_fields}
\title{
Internal functions for the SpatialVx package
}
\description{
Not to be called by the user.
}

\keyword{ internal}
